Class: LibLynxAPI::Identification

Inherits:
Object
  • Object
show all
Defined in:
lib/liblynx-api/client.rb

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Identification

Returns a new instance of Identification.



229
230
231
# File 'lib/liblynx-api/client.rb', line 229

def initialize(client)
  @client = client
end

Instance Method Details

#create(body = {}) ⇒ Object

create a new identification resource to try and identify an account to link a new session with

Parameters:

  • body:

    the object to pass as the request payload



236
237
238
# File 'lib/liblynx-api/client.rb', line 236

def create(body = {})
  @client.identification.create(body)
end

#info(identification_identity) ⇒ Object

retrieve a single identification object

Parameters:

  • identification_identity:


243
244
245
# File 'lib/liblynx-api/client.rb', line 243

def info(identification_identity)
  @client.identification.info(identification_identity)
end